@@ -25,6 +25,7 @@
 
 #include "partclone.h"
 #include "extfsclone.h"
+#include "progress.h"
 
 ext2_filsys  fs;
 char *EXECNAME = "partclone.extfs";
@@ -92,7 +93,7 @@ static unsigned long long get_used_blocks(){
 }
 
 /// readbitmap - cread and heck bitmap, reference dumpe2fs
-extern void readbitmap(char* device, image_head image_hdr, char* bitmap){
+extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui){
     errcode_t retval;
     unsigned long group;
     unsigned long long current_block, block;
@@ -101,8 +102,9 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap){
     int block_nbytes;
     unsigned long long blk_itr;
     int bg_flags = 0;
-
     int debug = 2;
+    int start = 0;
+    int bit_size = 1;
 
     log_mesg(2, 0, 0, debug, "readbitmap %i\n",bitmap);
 
@@ -124,6 +126,10 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap){
     current_block = 0;
     blk_itr = fs->super->s_first_data_block;
 
+    /// init progress
+    progress_bar	prog;		/// progress_bar structure defined in progress.h
+    progress_init(&prog, start, image_hdr.totalblock, bit_size);
+
     /// each group
     for (group = 0; group < fs->group_desc_count; group++) {
 
@@ -151,6 +157,8 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap){
 		    bitmap[current_block] = 1;
 		    log_mesg(3, 0, 0, debug, "used block %lu at group %i\n", (current_block), group);
 		}
+		/// update progress
+		update_pui(&prog, current_block, 0);//keep update
 	    }
 	    blk_itr += fs->super->s_blocks_per_group;
 	}
@@ -162,6 +170,8 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap){
     if (free != fs->super->s_free_blocks_count)
 	log_mesg(0, 1, 1, debug, "bitmap free count err, free:%i\n", free);
     fs_close();
+    /// update progress
+    update_pui(&prog, 1, 1);//finish
 }
 
 /// get extfs type
