@@ -34,11 +34,10 @@
 #include <stdlib.h>
 #include <errno.h>
 #include "gettext.h"
-#include "version.c"
 #include <linux/fs.h>
 #define _(STRING) gettext(STRING)
 //#define PACKAGE "partclone"
-
+#include "version.h"
 #include "partclone.h"
 
 #if defined(linux) && defined(_IO) && !defined(BLKGETSIZE)
@@ -72,7 +71,7 @@ extern void usage(void)
             "    -o,  --output FILE      Output FILE\n"
             "    -O   --overwrite FILE   Output FILE, overwriting if exists\n"
             "    -s,  --source FILE      Source FILE\n"
-            "    -L,  --logfile FILE      Log FILE\n"
+            "    -L,  --logfile FILE     Log FILE\n"
 #ifndef	RESTORE
             "    -c,  --clone            Save to the special image format\n"
             "    -r,  --restore          Restore from the special image format\n"
@@ -122,6 +121,8 @@ extern void parse_options(int argc, char **argv, cmd_opt* opt)
     opt->debug = 0;
     opt->rescue = 0;
     opt->check = 1;
+    opt->logfile = "/var/log/partclone.log";
+
 #ifdef RESTORE
     opt->restore++;
     mode++;
@@ -363,20 +364,16 @@ extern void close_ncurses(){
 
 /**
  * debug message
- * open_log	- to open file /var/log/partclone.log
+ * open_log	- to open file default is /var/log/partclone.log
  * log_mesg	- write log to the file
  *		- write log and exit 
  *		- write to stderr...
  * close_log	- to close file /var/log/partclone.log
  */
 extern void open_log(char* source){
-    if (source){
-        msg = fopen(source,"w");
-    } else {
-        msg = fopen("/var/log/partclone.log","w");
-    }
+    msg = fopen(source,"w");
     if(msg == NULL){
-        fprintf(stderr, "open /var/log/partclone.log error\n");
+        fprintf(stderr, "open logfile %s error\n", source);
         exit(0);
     }
 }
@@ -441,7 +438,7 @@ extern void log_mesg(int log_level, int log_exit, int log_stderr, int debug, con
     /// exit if lexit true
     if ((!opt.force) && (log_exit)){
         close_ncurses();
-        fprintf(stderr, "Partclone fail, please check /var/log/partclone.log !\n");
+        fprintf(stderr, "Partclone fail, please check %s !\n", opt.logfile);
         exit(1);
     }
 }
@@ -904,12 +901,14 @@ extern void print_partclone_info(cmd_opt opt){
     textdomain(PACKAGE);
     //log_mesg(0, 0, 0, "%s v%s \n", EXEC_NAME, VERSION);
     log_mesg(0, 0, 1, debug, _("Partclone v%s (%s) http://partclone.org\n"), VERSION, svn_version);
-    if (opt.clone)
-        log_mesg(0, 0, 1, debug, _("Starting clone device (%s) to image (%s)\n"), opt.source, opt.target);	
+    if (opt.chkimg)
+        log_mesg(0, 0, 1, debug, _("Starting to check image (%s)\n"), opt.source);	
+    else if (opt.clone)
+        log_mesg(0, 0, 1, debug, _("Starting to clone device (%s) to image (%s)\n"), opt.source, opt.target);	
     else if(opt.restore)
-        log_mesg(0, 0, 1, debug, _("Starting restore image (%s) to device (%s)\n"), opt.source, opt.target);
+        log_mesg(0, 0, 1, debug, _("Starting to restore image (%s) to device (%s)\n"), opt.source, opt.target);
     else if(opt.dd)
-        log_mesg(0, 0, 1, debug, _("Starting back up device(%s) to device(%s)\n"), opt.source, opt.target);
+        log_mesg(0, 0, 1, debug, _("Starting to back up device(%s) to device(%s)\n"), opt.source, opt.target);
     else
         log_mesg(0, 0, 1, debug, "unknow mode\n");
 }
@@ -952,7 +951,9 @@ extern void print_finish_info(cmd_opt opt){
     setlocale(LC_ALL, "");
     bindtextdomain(PACKAGE, LOCALEDIR);
     textdomain(PACKAGE);
-    if (opt.clone)
+    if (opt.chkimg)
+        log_mesg(0, 0, 1, debug, _("Partclone successfully checkd the image (%s)\n"), opt.source);	
+    else if (opt.clone)
         log_mesg(0, 0, 1, debug, _("Partclone successfully cloned the device (%s) to the image (%s)\n"), opt.source, opt.target);	
     else if(opt.restore)
         log_mesg(0, 0, 1, debug, _("Partclone successfully restored the image (%s) to the device (%s)\n"), opt.source, opt.target);
@@ -995,3 +996,4 @@ extern void dd_bitmap(image_head image_hdr, char* bitmap){
         bitmap[block] = 1; 
 
 }
+
